==> nextcloud-25.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/viewer/l10n/cs.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Prohlížeč",
    "Simple file viewer with slideshow for media" : "Jednoduchý prohlížeč souborů s režimem prezentace pro média",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Ukažte fotky a videa z vaší nedávné dovolené jako ve filmu; předveďte ukázku vaší nejnovější novely přímo z Nextcloud; vyberte nejlepší GIF animaci z vaší sbírky – to vše díky přímému náhledu vašich oblíbených souborů a mnoho dalšího!",
    "Your browser does not support audio." : "Váš prohlížeč nepodporuje zvuk.",
    "Error loading {name}" : "Chyba načítání {name}",
    "Image saved" : "Obrázek uložen",
    "Unsaved changes" : "Neuložené změny",
    "Drop changes" : "Zahodit změny",
    "Your browser does not support videos." : "Vámi používaný webový prohlížeč nepodporuje videa.",
    "Edit" : "Upravit",
    "Open sidebar" : "Otevřít postranní panel",
    "Download" : "Stáhnout",
    "Delete" : "Smazat",
    "There is no plugin available to display this file type" : "Pro zobrazení tohoto typu souboru není k dispozici žádný zásuvný modul",
    "View" : "Zobrazit",
    "Name" : "Jméno",
    "Save" : "Uložit",
    "Save as" : "Uložit jako",
    "Back" : "Zpět",
    "Loading …" : "Načítání…",
    "Reset" : "Vrátit na výchozí hodnoty",
    "All changes will be lost." : "Veškeré změny budou ztraceny.",
    "Are you sure you want to continue?" : "Opravdu chcete pokračovat?",
    "Cancel" : "Storno",
    "Continue" : "Pokračovat",
    "Undo" : "Vrátit zpět",
    "Redo" : "Zopakovat",
    "Show original image" : "Zobrazit původní obrázek",
    "Zoom in" : "Přiblížit",
    "Zoom out" : "Oddálit",
    "Toggle zoom menu" : "Zobraz/nezobraz. nabídku zvětšení",
    "Adjust" : "Přizpůsobit",
    "Fine-tune" : "Jemné doladění",
    "Filters" : "Filtry",
    "Watermark" : "Vodoznak",
    "Draw" : "Nakreslit",
    "Resize" : "Změnit rozlišení",
    "Invalid image." : "Neplatný obrázek.",
    "Error while uploading the image." : "Chyba při nahrávání obrázku.",
    "are not images" : "nejsou obrázky",
    "is not an image" : "není obrázek",
    "to be uploaded" : "k nahrání",
    "Crop" : "Oříznout",
    "Original" : "Původní",
    "Custom" : "Uživatelsky určený",
    "Square" : "Čtverec",
    "Landscape" : "Krajina",
    "Portrait" : "Portrét",
    "Ellipse" : "Elipsa",
    "Classic TV" : "Klasická televize",
    "CinemaScope" : "Extrémně širokoúhlé",
    "Arrow" : "Šipka",
    "Blur" : "Rozmazat",
    "Brightness" : "Jas",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Vzít zpět svisl. převrácení",
    "Flip X" : "Převrátit svisle",
    "Un-flip Y" : "Vzít zpět vodorov. převrácení",
    "Flip Y" : "Převrátit vodorovně",
    "HSV" : "HSV",
    "Hue" : "Odstín",
    "Saturation" : "Saturace",
    "Value" : "Hodnota",
    "Image" : "Obrázek",
    "Importing …" : "Importování…",
    "+ Add image" : "+ Přidat obrázek",
    "Line" : "Čára",
    "Pen" : "Pero",
    "Polygon" : "Mnohoúhelník",
    "Sides" : "Stran",
    "Rectangle" : "Obdélník",
    "Corner Radius" : "Zaoblení rohů (poloměr)",
    "Width in pixels" : "Šířka v pixelex",
    "Height in pixels" : "Výška v pixelech",
    "Toggle ratio lock" : "Vyp/zap. zám. poměru stran",
    "Reset to original image size" : "Vrátit k původní velikosti obrázku",
    "Rotate" : "Otočit",
    "Text" : "Text",
    "Text spacing" : "Rozestupy textu",
    "Text alignment" : "Zarovnání textu",
    "Font family" : "Skupina písem",
    "Size" : "Velikost",
    "Letter spacing" : "Rozestupy znaků",
    "Line height" : "Výška řádku",
    "Warmth" : "Teplota",
    "+ Add watermark" : "+ přidat vodotisk",
    "Choose watermark type" : "Zvolte typ vodotisku",
    "Upload watermark" : "Nahrát vodotisk",
    "Add as text" : "Přidat jako text",
    "Padding" : "Doplňování",
    "Shadow" : "Stín",
    "Horizontal" : "Vodorovné",
    "Vertical" : "Svislé",
    "Opacity" : "(Ne)průhlednost",
    "Position" : "Pozice",
    "Stroke" : "Čára",
    "Save image as" : "Uložit obrázek jako",
    "Extension" : "Přípona",
    "Name is required." : "Jméno je povinné.",
    "Quality" : "Kvalita",
    "Saved image size (width x height)" : "Velikost uloženého obrázku (šířka x výška)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Pozn.: označená oblast ořezu je menší než použitá změna rozlišení, což může způsobit snížení kvality",
    "Actual size (100%)" : "Skutečná velikost (100%)",
    "Fit size" : "Přizpůsobit velikost",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Ukažte fotky a videa z vaší nedávné dovolené jako ve filmu; předveďte ukázku vaší nejnovější novely přímo z Nextcloud; vyberte nejlepší GIF animaci z vaší sbírky – to vše díky přímému náhledu vašich oblíbených souborů a mnoho dalšího!"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-30.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/viewer/l10n/cs.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Prohlížeč",
    "Simple file viewer with slideshow for media" : "Jednoduchý prohlížeč souborů s režimem prezentace pro média",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Ukažte fotky a videa z vaší nedávné dovolené jako ve filmu; předveďte ukázku vaší nejnovější novely přímo z Nextcloud; vyberte nejlepší GIF animaci z vaší sbírky – to vše díky přímému náhledu vašich oblíbených souborů a mnoho dalšího!",
    "Your browser does not support audio." : "Váš prohlížeč nepodporuje zvuk.",
    "Error loading {name}" : "Chyba načítání {name}",
    "Image saved" : "Obrázek uložen",
    "Error saving image" : "Chyb při ukládání obrázku",
    "Unsaved changes" : "Neuložené změny",
    "Drop changes" : "Zahodit změny",
    "Play the live photo" : "Přehrát živé video",
    "LIVE" : "ŽIVĚ",
    "Your browser does not support videos." : "Vámi používaný webový prohlížeč nepodporuje videa.",
    "Edit" : "Upravit",
    "Exit full screen" : "Opustit celou obrazovku",
    "Full screen" : "Na celou obrazovku",
    "Open sidebar" : "Otevřít postranní panel",
    "Download" : "Stáhnout",
    "Delete" : "Smazat",
    "This file no longer exists" : "Tento soubor už neexistuje",
    "There is no plugin available to display this file type" : "Pro zobrazení tohoto typu souboru není k dispozici žádný zásuvný modul",
    "View" : "Zobrazit",
    "Name" : "Název",
    "Save" : "Uložit",
    "Save as" : "Uložit jako",
    "Back" : "Zpět",
    "Loading …" : "Načítání…",
    "Reset" : "Vrátit na výchozí hodnoty",
    "All changes will be lost." : "Veškeré změny budou ztraceny.",
    "Are you sure you want to continue?" : "Opravdu chcete pokračovat?",
    "Cancel" : "Storno",
    "Apply" : "Použít",
    "Warning" : "Varování",
    "Confirm" : "Potvrdit",
    "Discard changes" : "Zahodit změny",
    "Undo" : "Vrátit zpět",
    "Redo" : "Zopakovat",
    "Show original image" : "Zobrazit původní obrázek",
    "Zoom in" : "Přiblížit",
    "Zoom out" : "Oddálit",
    "Toggle zoom menu" : "Zobraz/nezobraz. nabídku zvětšení",
    "Adjust" : "Přizpůsobit",
    "Fine-tune" : "Jemné doladění",
    "Filters" : "Filtry",
    "Watermark" : "Vodoznak",
    "Draw" : "Nakreslit",
    "Resize" : "Změnit rozlišení",
    "Invalid image." : "Neplatný obrázek.",
    "Error while uploading the image." : "Chyba při nahrávání obrázku.",
    "are not images" : "nejsou obrázky",
    "is not an image" : "není obrázek",
    "to be uploaded" : "k nahrání",
    "Crop" : "Oříznout",
    "Original" : "Původní",
    "Custom" : "Uživatelsky určený",
    "Square" : "Čtverec",
    "Landscape" : "Obdélník na šířku",
    "Portrait" : "Obdélník na výšku",
    "Ellipse" : "Elipsa",
    "Classic TV" : "Klasická televize",
    "CinemaScope" : "Extrémně širokoúhlé",
    "Arrow" : "Šipka",
    "Blur" : "Rozmazat",
    "Brightness" : "Jas",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Vzít zpět svisl. převrácení",
    "Flip X" : "Převrátit svisle",
    "Un-flip Y" : "Vzít zpět vodorov. převrácení",
    "Flip Y" : "Převrátit vodorovně",
    "HSV" : "HSV",
    "Hue" : "Odstín",
    "Saturation" : "Saturace",
    "Value" : "Hodnota",
    "Image" : "Obrázek",
    "Importing …" : "Importování…",
    "+ Add image" : "+ Přidat obrázek",
    "Line" : "Čára",
    "Pen" : "Pero",
    "Polygon" : "Mnohoúhelník",
    "Sides" : "Stran",
    "Rectangle" : "Obdélník",
    "Corner Radius" : "Zaoblení rohů (poloměr)",
    "Width in pixels" : "Šířka v pixelech",
    "Height in pixels" : "Výška v pixelech",
    "Toggle ratio lock" : "Vyp/zap. zám. poměru stran",
    "Reset to original image size" : "Vrátit k původní velikosti obrázku",
    "Rotate" : "Otočit",
    "Text" : "Text",
    "Text spacing" : "Rozestupy textu",
    "Text alignment" : "Zarovnání textu",
    "Font family" : "Skupina písem",
    "Size" : "Velikost",
    "Letter spacing" : "Rozestupy znaků",
    "Line height" : "Výška řádku",
    "Warmth" : "Teplota",
    "+ Add watermark" : "+ přidat vodotisk",
    "Choose watermark type" : "Zvolte typ vodotisku",
    "Upload watermark" : "Nahrát vodotisk",
    "Add as text" : "Přidat jako text",
    "Padding" : "Doplňování",
    "Shadow" : "Stín",
    "Horizontal" : "Vodorovné",
    "Vertical" : "Svislé",
    "Opacity" : "(Ne)průhlednost",
    "Position" : "Pozice",
    "Stroke" : "Čára",
    "Save image as" : "Uložit obrázek jako",
    "Extension" : "Přípona",
    "Name is required." : "Je třeba vyplnit název.",
    "Quality" : "Kvalita",
    "Saved image size (width x height)" : "Velikost uloženého obrázku (šířka x výška)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Pozn.: označená oblast ořezu je menší než použitá změna rozlišení, což může způsobit snížení kvality",
    "Actual size (100%)" : "Skutečná velikost (100%)",
    "Fit size" : "Přizpůsobit velikost",
    "Menu" : "Nabídka",
    "Width" : "Šířka",
    "Height" : "Výška",
    "Continue" : "Pokračovat"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
